@@ -14,14 +14,11 @@
 #  limitations under the License.
 
 import blockdiag.DiagramDraw
-from blockdiag.utils import XY
 
 
 class DiagramDraw(blockdiag.DiagramDraw.DiagramDraw):
     def _draw_elements(self, **kwargs):
         m = self.metrics
-        pagesize = self.pagesize()
-        margin = m.page_margin
 
         # render frame of activity lanes
         frame = m.frame(self.diagram.lanes)
@@ -42,7 +39,7 @@ class DiagramDraw(blockdiag.DiagramDraw.DiagramDraw):
 
             textbox = m.lane_textbox(lane)
             self.drawer.textarea(textbox, label, fill=self.fill,
-                                 fontsize=self.metrics.fontsize_for(lane))
+                                 font=self.metrics.font_for(lane))
 
         super(DiagramDraw, self)._draw_elements(**kwargs)
 
