@@ -35,12 +35,8 @@ At the moment, the parser builds only a parse tree, not an abstract syntax tree
   [1]: http://www.graphviz.org/doc/info/lang.html
 '''
 
-import os
-import sys
 import codecs
 from re import MULTILINE, DOTALL
-from pprint import pformat
-from funcparserlib.util import pretty_tree
 from funcparserlib.lexer import make_tokenizer, Token, LexerError
 from funcparserlib.parser import (some, a, maybe, many, finished, skip,
     oneplus, forward_decl, NoParseError)
@@ -54,6 +50,7 @@ Node = namedtuple('Node', 'id attrs')
 Attr = namedtuple('Attr', 'name value')
 Edge = namedtuple('Edge', 'nodes attrs')
 DefAttrs = namedtuple('DefAttrs', 'object attrs')
+AttrPlugin = namedtuple('AttrPlugin', 'name attrs')
 AttrClass = namedtuple('AttrClass', 'name attrs')
 
 
@@ -68,7 +65,7 @@ def tokenize(str):
         ('Comment', (r'//.*',)),
         ('NL',      (r'[\r\n]+',)),
         ('Space',   (r'[ \t\r\n]+',)),
-        ('Name',    (ur'[A-Za-z_\u0080-\uffff]'
+        ('Name',    (ur'[A-Za-z_0-9\u0080-\uffff]'
                      ur'[A-Za-z_\-.0-9\u0080-\uffff]*',)),
         ('Op',      (r'[{};,=\[\]]|(<->)|(<-)|(--)|(->)',)),
         ('Number',  (r'-?(\.[0-9]+)|([0-9]+(\.[0-9]*)?)',)),
@@ -106,10 +103,6 @@ def parse(seq):
     attr_list = (
         many(op_('[') + many(a_list) + op_(']'))
         >> flatten)
-    attr_stmt = (
-       (n('graph') | n('node') | n('edge')) +
-       attr_list
-       >> unarg(DefAttrs))
     graph_attr = id + op_('=') + id >> make_graph_attr
     node_stmt = node_id + attr_list >> unarg(Node)
     # We use a forward_decl becaue of circular definitions like (stmt_list ->
@@ -122,8 +115,7 @@ def parse(seq):
         attr_list
         >> unarg(make_edge))
     lane_stmt = (
-          attr_stmt
-        | edge_stmt
+          edge_stmt
         | graph_attr
         | node_stmt
     )
@@ -140,9 +132,14 @@ def parse(seq):
         node_id +
         attr_list
         >> unarg(AttrClass))
+    plugin_stmt = (
+        skip(n('plugin')) +
+        node_id +
+        attr_list
+        >> unarg(AttrPlugin))
     stmt = (
-          attr_stmt
-        | class_stmt
+          class_stmt
+        | plugin_stmt
         | edge_stmt
         | lane_stmt
         | graph_attr
@@ -150,7 +147,7 @@ def parse(seq):
     )
     stmt_list = many(stmt + skip(maybe(op(';'))))
     graph = (
-        maybe(n('diagram')) +
+        maybe(n('diagram') | n('actdiag')) +
         maybe(id) +
         op_('{') +
         stmt_list +
@@ -161,46 +158,6 @@ def parse(seq):
     return dotfile.parse(seq)
 
 
-def pretty_parse_tree(x):
-    'object -> str'
-    Pair = namedtuple('Pair', 'first second')
-    p = lambda x, y: Pair(x, y)
-
-    def kids(x):
-        'object -> list(object)'
-        if isinstance(x, (Graph, SubGraph)):
-            return [p('stmts', x.stmts)]
-        elif isinstance(x, (Node, DefAttrs)):
-            return [p('attrs', x.attrs)]
-        elif isinstance(x, Edge):
-            return [p('nodes', x.nodes), p('attrs', x.attrs)]
-        elif isinstance(x, Pair):
-            return x.second
-        else:
-            return []
-
-    def show(x):
-        'object -> str'
-        if isinstance(x, Pair):
-            return x.first
-        elif isinstance(x, Graph):
-            return 'Graph [id=%s, type=%s]' % (
-                x.id, x.type)
-        elif isinstance(x, SubGraph):
-            return 'SubGraph [id=%s]' % x.id
-        elif isinstance(x, Edge):
-            return 'Edge'
-        elif isinstance(x, Attr):
-            return 'Attr [name=%s, value=%s]' % (x.name, x.value)
-        elif isinstance(x, DefAttrs):
-            return 'DefAttrs [object=%s]' % x.object
-        elif isinstance(x, Node):
-            return 'Node [id=%s]' % x.id
-        else:
-            return unicode(x)
-    return pretty_tree(x, kids, show)
-
-
 def parse_string(string):
     try:
         return parse(tokenize(string))
