@@ -13,11 +13,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import re
-import sys
 import blockdiag.elements
 from blockdiag.elements import *
-from blockdiag.utils import XY
 
 
 class DiagramNode(blockdiag.elements.DiagramNode):
