@@ -13,5 +13,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from actdiag import diagparser, builder, DiagramDraw
+from blockdiag.utils import collections
+from blockdiag.utils.fontmap import FontMap
+from actdiag import command, diagparser, builder, DiagramDraw
 from actdiag.utils.rst.directives import actdiag, ActdiagDirective
